@@ -1,5 +1,5 @@
 .First.lib <- function(library,section){
-	if(!require("syskern",  warn.conflicts=F)) 
+	if(!require("syskern")) 
 	warning("This package requires the syskern package.") # only for is.S ?
 	invisible()
 }
